import type { ExtractPropTypes, PropType } from 'vue';
import type { AvatarSize } from './interface';
import type { IconSlotType } from '../../../types';
import type { ImageFit } from '../../image';
export declare const Props: {
    /**
     * avatar size.
     */
    readonly size: {
        readonly type: PropType<AvatarSize>;
        readonly default: "";
    };
    /**
     * avatar shape.
     */
    readonly shape: {
        readonly type: PropType<"circle" | "square">;
        readonly default: "circle";
    };
    /**
     * representation type to icon, more info on icon component.
     */
    readonly icon: {
        readonly type: PropType<IconSlotType>;
    };
    /**
     * the source of the image for an image avatar.
     */
    readonly src: {
        readonly type: StringConstructor;
        readonly default: "";
    };
    /**
     * native attribute `alt` of image avatar.
     */
    readonly alt: StringConstructor;
    /**
     * native attribute srcset of image avatar.
     */
    readonly srcSet: StringConstructor;
    /**
     * set how the image fit its container for an image avatar.
     * https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit
     */
    readonly fit: {
        readonly type: PropType<ImageFit>;
        readonly default: "cover";
    };
};
export declare const Emits: {
    error: (evt: Event) => evt is Event;
};
export type AvatarEmits = typeof Emits;
export type AvatarProps = ExtractPropTypes<typeof Props>;
