import type { ExtractPropTypes, PropType } from 'vue';
export declare const Props: {
    /**
     *  preview link list.
     */
    readonly urlList: {
        readonly type: PropType<string[]>;
        readonly default: () => readonly [];
    };
    /**
     *  preview backdrop z-index.
     */
    readonly zIndex: {
        readonly type: NumberConstructor;
    };
    /**
     *  the initial preview image index, less than or equal to the length of `url-list`.
     */
    readonly initialIndex: {
        readonly type: NumberConstructor;
        readonly default: 0;
    };
    /**
     *  whether preview is infinite.
     */
    readonly infinite: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     *  whether user can emit close event when clicking backdrop.
     */
    readonly hideOnClickModal: BooleanConstructor;
    /**
     *  whether to append image itself to body. A nested parent element attribute transform should have this attribute set to `true`.
     */
    readonly teleported: BooleanConstructor;
    /**
     *  whether the image-viewer can be closed by pressing ESC.
     */
    readonly closeOnPressEscape: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     *  the zoom rate of the image viewer zoom event.
     */
    readonly zoomRate: {
        readonly type: NumberConstructor;
        readonly default: 1.2;
    };
    /**
     *  the min scale of the image viewer zoom event.
     */
    readonly minScale: {
        readonly type: NumberConstructor;
        readonly default: 0.2;
    };
    /**
     *  the max scale of the image viewer zoom event.
     */
    readonly maxScale: {
        readonly type: NumberConstructor;
        readonly default: 7;
    };
};
export declare const Emits: {
    close: () => boolean;
    switch: (index: number) => boolean;
    rotate: (deg: number) => boolean;
};
export type ImagePreviewProps = ExtractPropTypes<typeof Props>;
