import type { ExtractPropTypes, PropType } from 'vue';
import type { ImageFit, ImageLoading } from './interface';
export declare const Props: {
    /**
     * when enabling preview, use this flag to control whether clicking on backdrop can exit preview mode.
     */
    readonly hideOnClickModal: BooleanConstructor;
    /**
     * image source, same as native.
     */
    readonly src: {
        readonly type: StringConstructor;
        readonly default: "";
    };
    /**
     * indicate how the image should be resized to fit its container, same as [object-fit](https://developer.mozilla.org/en-US/docs/Web/CSS/object-fit).
     */
    readonly fit: {
        readonly type: PropType<ImageFit>;
    };
    /**
     * Indicates how the browser should load the image, same as [native](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img#attr-loading)
     */
    readonly loading: {
        readonly type: PropType<ImageLoading>;
    };
    /**
     * whether to use lazy load.
     */
    readonly lazy: BooleanConstructor;
    /**
     * the container to add scroll listener when using lazy load.
     */
    readonly scrollContainer: {
        readonly type: PropType<string | HTMLElement | undefined>;
    };
    /**
     * allow big image preview.
     */
    readonly previewSrcList: {
        readonly type: PropType<string[]>;
        readonly default: () => readonly [];
    };
    /**
     * whether to append image-viewer to body. A nested parent element attribute transform should have this attribute set to `true`.
     */
    readonly previewTeleported: BooleanConstructor;
    /**
     * set image preview z-index.
     */
    readonly zIndex: {
        readonly type: NumberConstructor;
    };
    /**
     * initial preview image index, less than the length of `url-list`.
     */
    readonly initialIndex: {
        readonly type: NumberConstructor;
        readonly default: 0;
    };
    /**
     * whether the viewer preview is infinite.
     */
    readonly infinite: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * whether the image-viewer can be closed by pressing ESC.
     */
    readonly closeOnPressEscape: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /**
     * the zoom rate of the image viewer zoom event
     */
    readonly zoomRate: {
        readonly type: NumberConstructor;
        readonly default: 1.2;
    };
    /**
     * the min scale of the image viewer zoom event.
     */
    readonly minScale: {
        readonly type: NumberConstructor;
        readonly default: 0.2;
    };
    /**
     * the max scale of the image viewer zoom event.
     */
    readonly maxScale: {
        readonly type: NumberConstructor;
        readonly default: 7;
    };
};
export declare const Emits: {
    load: (evt: Event) => boolean;
    error: (evt: Event) => boolean;
    switch: (val: number) => boolean;
    close: () => boolean;
    show: () => boolean;
};
export type ImageProps = ExtractPropTypes<typeof Props>;
