import type { ExtractPropTypes, PropType, StyleValue } from 'vue';
import type { TextareaAutoSize, TextareaResize } from './interface';
export declare const Props: {
    /** 绑定值 */
    readonly modelValue: {
        readonly type: PropType<string | number>;
        readonly default: "";
    };
    /**
     * control the resizability
     */
    readonly resize: {
        readonly type: PropType<TextareaResize>;
    };
    /**
     * native input autocomplete
     */
    readonly autocomplete: {
        readonly type: StringConstructor;
        readonly default: "off";
    };
    /**
     * 最大输入长度
     *
     * @see maxlength https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-maxlength
     */
    readonly maxlength: {
        readonly type: NumberConstructor;
    };
    /**
     *  placeholder
     */
    readonly placeholder: {
        readonly type: StringConstructor;
    };
    /**
     *  native input readonly
     */
    /**
     *  whether to disable
     */
    readonly disabled: BooleanConstructor;
    readonly readonly: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
    readonly textareaStyle: {
        readonly type: PropType<StyleValue>;
        readonly default: () => StyleValue;
    };
    /**
     *  input tabindex
     */
    readonly tabindex: {
        readonly type: PropType<string | number>;
        readonly default: 0;
    };
    /**
     *  native input aria-label
     */
    readonly label: {
        readonly type: StringConstructor;
        readonly default: undefined;
    };
    /**
     *  format content
     */
    readonly formatter: {
        readonly type: FunctionConstructor;
    };
    /**
     *  parse content
     */
    readonly parser: {
        readonly type: FunctionConstructor;
    };
    /**
     *  native input autofocus
     */
    readonly autofocus: {
        readonly type: BooleanConstructor;
        readonly default: false;
    };
    readonly autosize: {
        readonly type: PropType<TextareaAutoSize>;
        readonly default: false;
    };
};
export type TextareaProps = ExtractPropTypes<typeof Props>;
