import type { ExtractPropTypes, PropType } from 'vue';
import type { WatermarkFontType } from './interface';
export declare const Props: {
    /**
     * @description The z-index of the appended watermark element
     */
    readonly zIndex: {
        readonly type: NumberConstructor;
        readonly default: 9;
    };
    /**
     * @description The rotation angle of the watermark
     */
    readonly rotate: {
        readonly type: NumberConstructor;
        readonly default: -22;
    };
    /**
     * @description The width of the watermark
     */
    readonly width: NumberConstructor;
    /**
     * @description The height of the watermark
     */
    readonly height: NumberConstructor;
    /**
     * @description Image source, it is recommended to export 2x or 3x image, high priority (support base64 format)
     */
    readonly image: StringConstructor;
    /**
     * @description Watermark text content
     */
    readonly content: {
        readonly type: PropType<string | string[]>;
        readonly default: "Fz Design";
    };
    /**
     * @description Text style
     */
    readonly font: {
        readonly type: PropType<WatermarkFontType>;
    };
    /**
     * @description The spacing between watermarks
     */
    readonly gap: {
        readonly type: PropType<[number, number]>;
        readonly default: () => number[];
    };
    /**
     * @description The offset of the watermark from the upper left corner of the container. The default is gap/2
     */
    readonly offset: {
        readonly type: PropType<[number, number]>;
    };
};
export type WatermarkProps = ExtractPropTypes<typeof Props>;
