import type { ExtractPropTypes, PropType } from 'vue';
import type { ComponentSize, IconSlotType } from '../../../types';
import type { InputType } from './interface';
export declare const Props: {
    /** 绑定值 */
    readonly modelValue: {
        readonly type: PropType<string | number>;
        readonly default: "";
    };
    /**
     * 类型
     *
     * 文字输入框或者密码输入框
     *
     * @values text password number
     * @default text
     */
    readonly type: {
        readonly type: PropType<InputType>;
        readonly default: "text";
    };
    /**
     * 尺寸
     *
     * @values large default small
     */
    readonly size: {
        readonly type: PropType<ComponentSize>;
    };
    /**
     * 是否禁用
     *
     * @see disabled https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-disabled
     */
    readonly disabled: {
        readonly type: BooleanConstructor;
    };
    /**
     * 是否只读
     *
     * @see readonly https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-readonly
     */
    readonly readonly: {
        readonly type: BooleanConstructor;
    };
    /**
     * 最大输入长度
     *
     * @see maxlength https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-maxlength
     */
    readonly maxlength: {
        readonly type: NumberConstructor;
    };
    /**
     * 是否自动获取焦点
     *
     * @see autofocus https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-autofocus
     */
    readonly autofocus: {
        readonly type: BooleanConstructor;
    };
    /**
     * 占位符
     *
     * @see placeholder https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#attr-placeholder
     */
    readonly placeholder: {
        readonly type: StringConstructor;
    };
    /** 是否可清除 */
    readonly clearable: {
        readonly type: BooleanConstructor;
    };
    /** 是否可搜索 */
    readonly search: {
        readonly type: BooleanConstructor;
    };
    /** 是否显示查看密码的按钮 */
    readonly showPassword: {
        readonly type: BooleanConstructor;
    };
    /** 后缀 icon */
    readonly suffixIcon: {
        readonly type: PropType<IconSlotType>;
    };
    /** 前缀 icon */
    readonly prefixIcon: {
        readonly type: PropType<IconSlotType>;
    };
    /**
     *  input tabindex
     */
    readonly tabindex: {
        readonly type: PropType<string | number>;
        readonly default: 0;
    };
    /**
     *  native input aria-label
     */
    readonly label: {
        readonly type: StringConstructor;
        readonly default: undefined;
    };
    /**
     * 是否开启自动填充特性提示
     *
     * 注意这不是一个布尔属性！
     *
     * 详情配置可参考
     *
     * @see HTML属性autocomplete https://developer.mozilla.org/zh-CN/docs/Web/HTML/Attributes/autocomplete
     * @see autocomplete https://developer.mozilla.org/zh-CN/docs/Web/HTML/Element/Input#autocomplete
     */
    readonly autocomplete: {
        readonly type: StringConstructor;
        readonly default: "off";
    };
};
export declare const Emits: {
    input: (value: string | number) => boolean;
    change: (value: string | number) => boolean;
    focus: (evt: FocusEvent) => boolean;
    blur: (evt: FocusEvent) => boolean;
    search: (value: string | number, evt: MouseEvent | KeyboardEvent) => boolean;
    clear: () => boolean;
};
export type InputProps = ExtractPropTypes<typeof Props>;
