import type { RendererNode, RendererElement, ExtractPropTypes,  PropType,  VNode } from 'vue';
import type { NotificationPlacement } from './interface';
import type { ComponentType, IconSlotType } from '../../../types';
export declare const Props: {
    /** 通知标题 */
    readonly title: {
        readonly type: PropType<string | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>>;
        readonly default: () => null;
    };
    /** 通知文本 */
    readonly message: {
        readonly type: PropType<string | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>>;
        readonly default: () => null;
    };
    /**
     * 消息类型
     *
     * @values default primary success danger warning
     */
    readonly type: {
        readonly type: PropType<ComponentType>;
        readonly default: "default";
    };
    /** 是否可关闭 */
    readonly closable: BooleanConstructor;
    /** 显示时间，单位为毫秒。 设为 0 则不会自动关闭 */
    readonly duration: {
        readonly type: NumberConstructor;
        readonly default: 2500;
    };
    /** 是否为圆角类型 */
    readonly round: BooleanConstructor;
    /** 是否显示按钮 */
    readonly showIcon: {
        readonly type: BooleanConstructor;
        readonly default: true;
    };
    /** 消息 icon */
    readonly icon: {
        readonly type: PropType<IconSlotType>;
        readonly default: () => null;
    };
    /** 字体颜色 */
    readonly color: StringConstructor;
    /** 自定义背景色 */
    readonly background: StringConstructor;
    /** 偏移距离 */
    readonly offset: {
        readonly type: NumberConstructor;
        readonly default: 20;
    };
    /**
     * 弹出位置
     */
    readonly placement: {
        readonly type: PropType<NotificationPlacement>;
        readonly default: "top";
    };
    /** 层级 */
    readonly zIndex: NumberConstructor;
    /** 关闭按钮 */
    readonly closeBtn: {
        readonly type: PropType<string | VNode<RendererNode, RendererElement, {
            [key: string]: any;
        }>>;
        readonly default: () => null;
    };
    /** 关闭回调 */
    readonly onClose: {
        readonly type: PropType<(evt?: MouseEvent) => void>;
        readonly default: () => null;
    };
};
export type NotificationProps = ExtractPropTypes<typeof Props>;
