import { type ExtractPropTypes, type PropType, type StyleValue, type VNodeChild } from 'vue';
import type { Arrayable } from '../../../types';
export declare const Props: {
    /**
     *  Placement direction
     */
    readonly direction: {
        readonly type: PropType<"horizontal" | "vertical">;
        readonly default: "horizontal";
    };
    /**
     *  Classname
     */
    readonly class: {
        readonly type: PropType<Arrayable<string | Record<string, boolean>>>;
        readonly default: "";
    };
    /**
     *  Extra style rules
     */
    readonly style: {
        readonly type: PropType<StyleValue>;
        readonly default: "";
    };
    /**
     *  Controls the alignment of items
     */
    readonly alignment: {
        readonly type: StringConstructor;
        readonly default: "center";
    };
    /**
     * Prefix for space-items
     */
    readonly prefixCls: {
        readonly type: StringConstructor;
    };
    /**
     *  Spacer
     */
    readonly spacer: {
        readonly type: PropType<VNodeChild>;
        readonly default: null;
        readonly validator: (val: unknown) => boolean;
    };
    /**
     *  Auto wrapping
     */
    readonly wrap: BooleanConstructor;
    /**
     *  Whether to fill the container
     */
    readonly fill: BooleanConstructor;
    /**
     *  Ratio of fill
     */
    readonly fillRatio: {
        readonly type: NumberConstructor;
        readonly default: 100;
    };
    /**
     * Spacing size
     */
    readonly size: {
        readonly type: PropType<Arrayable<number>>;
        readonly validator: (val: unknown) => val is number | [number, number];
    };
};
export type SpaceProps = ExtractPropTypes<typeof Props>;
